# chname

chname renames files in powerful ways.

```
Usage:
    chname append [--dry-run --quiet --verbose] <suffix> <files>...
    chname lower [--dry-run --quiet --verbose] <files>...
    chname merge [--dry-run --quiet --verbose] <directory> <files>...
    chname order [--dry-run --quiet --verbose] <files>...
    chname remove [--dry-run --quiet --verbose] <pattern> <files>...
    chname prepend [--dry-run --quiet --verbose] <prefix> <files>...
    chname substitute [--dry-run --quiet --verbose] <old> <new> <files>...
    chname titles [--dry-run --quiet --verbose] <input> <files>...
    chname usage
    chname (-h | --help)
    chname --version

Options:
    --dry-run                  Show what would be done, but don't actually do it
    -h, --help                 Show this help screen
    -q, --quiet                Quiet mode
    -v, --verbose              Verbose mode
    --version                  Prints the version
```

## Installation

```bash
pip install chname
```

## License

chname is freeware released under the [MIT License](https://github.com/scholnicks/chname/blob/main/LICENSE).
